@@ -6,11 +6,19 @@ Author(s):
 """
 import importlib
 from primrose.base.transformer_sequence import TransformerSequence
-from primrose.transformers.sklearn_preprocessing_transformer import SklearnPreprocessingTransformer
+from primrose.transformers.sklearn_preprocessing_transformer import (
+    SklearnPreprocessingTransformer,
+)
 from primrose.data_object import DataObjectResponseType
 from primrose.pipelines.train_test_split import TrainTestSplit
+import warnings
+
 
 class SklearnPreprocessingPipeline(TrainTestSplit):
+    warnings.warn(
+        "SklearnPreprocessingPipeline will be deprecated in a future release. Please use TransformerPipeline instead",
+        DeprecationWarning,
+    )
 
     @staticmethod
     def necessary_config(node_config):
@@ -20,7 +28,7 @@ class SklearnPreprocessingPipeline(TrainTestSplit):
             set of keys
 
         """
-        return set(['operations']).union(TrainTestSplit.necessary_config(node_config))
+        return set(["operations"]).union(TrainTestSplit.necessary_config(node_config))
 
     def init_pipeline(self):
         """create the pipeline's TransformerSequence
@@ -33,10 +41,10 @@ class SklearnPreprocessingPipeline(TrainTestSplit):
 
         for operation in self.node_config["operations"]:
 
-            args = operation.get('args', None)
-            columns = operation.get('columns', None)
-            
-            p = self._instantiate_preprocessor(operation['class'], args, columns)
+            args = operation.get("args", None)
+            columns = operation.get("columns", None)
+
+            p = self._instantiate_preprocessor(operation["class"], args, columns)
             ts.add(p)
 
         return ts
@@ -44,23 +52,25 @@ class SklearnPreprocessingPipeline(TrainTestSplit):
     @staticmethod
     def _instantiate_preprocessor(classname, args=None, columns=None):
         """Import and validate user-defined sklearn preprocessor
-        
+
         Returns:
             SklearnPreprocessingTransformer
-        
+
         """
 
-        sk_module_name, sk_transformer_name = classname.split('.')
-        sk_module = importlib.import_module('sklearn.{}'.format(sk_module_name))
+        sk_module_name, sk_transformer_name = classname.split(".")
+        sk_module = importlib.import_module("sklearn.{}".format(sk_module_name))
 
         try:
             t = getattr(sk_module, sk_transformer_name)
         except AttributeError:
-            raise Exception('Preprocessor {} not found in {} module'.format(sk_transformer_name, sk_module_name))
+            raise Exception(
+                "Preprocessor {} not found in {} module".format(
+                    sk_transformer_name, sk_module_name
+                )
+            )
 
         if args:
             return SklearnPreprocessingTransformer(t(**args), columns)
 
         return SklearnPreprocessingTransformer(t(), columns)
-
-
